Crate kcr_scheduling_volcano_sh

Crate kcr_scheduling_volcano_sh 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the scheduling.volcano.sh group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

scheduling.volcano.sh/v1beta1

  • PodGroup
  • Queue

Modules

v1beta1