This crate contains kube-rs compatible bindings for Kubernetes custom resources for the scheduling.volcano.sh group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
scheduling.volcano.sh/v1beta1
PodGroupQueue